@@ -40,10 +40,11 @@ def WriteCache(name=str, content=str, dst=any):
 
         return 0
 
-def ReadCache(name=str, src=any):
+def ReadCache(name=str, src=any, rm=bool):
     """
     name = File name (include extension),
-    src = File location (do not include the file name)
+    src = File location (do not include the file name),
+    rm = Delete file after reading (True, False)
     """
 
     slashes = {"/", "\\"}
@@ -60,6 +61,10 @@ def ReadCache(name=str, src=any):
 
         a.close()
 
+        if rm == True:
+            import os
+            os.remove(f"{src}\\{name}")
+
         return b
 
     else:
@@ -70,6 +75,10 @@ def ReadCache(name=str, src=any):
 
         a.close()
 
+        if rm == True:
+            import os
+            os.remove(f"{src}\\{name}")
+
         return b
 
-#0.0.5
\ No newline at end of file
+#0.0.6
\ No newline at end of file
